@@ -17,15 +17,18 @@ describe 'placement::keystone::auth' do
         :configure_endpoint  => true,
         :service_name        => 'placement',
         :service_type        => 'placement',
-        :service_description => 'Placement Service',
+        :service_description => 'OpenStack Placement Service',
         :region              => 'RegionOne',
         :auth_name           => 'placement',
         :password            => 'placement_password',
         :email               => 'placement@localhost',
         :tenant              => 'services',
-        :public_url          => 'http://127.0.0.1/placement',
-        :internal_url        => 'http://127.0.0.1/placement',
-        :admin_url           => 'http://127.0.0.1/placement',
+        :roles               => ['admin'],
+        :system_scope        => 'all',
+        :system_roles        => [],
+        :public_url          => 'http://127.0.0.1:8778',
+        :internal_url        => 'http://127.0.0.1:8778',
+        :admin_url           => 'http://127.0.0.1:8778',
       ) }
     end
 
@@ -35,10 +38,13 @@ describe 'placement::keystone::auth' do
           :auth_name           => 'alt_placement',
           :email               => 'alt_placement@alt_localhost',
           :tenant              => 'alt_service',
+          :roles               => ['admin', 'service'],
+          :system_scope        => 'alt_all',
+          :system_roles        => ['admin', 'member', 'reader'],
           :configure_endpoint  => false,
           :configure_user      => false,
           :configure_user_role => false,
-          :service_description => 'Alternative Placement Service',
+          :service_description => 'Alternative OpenStack Placement Service',
           :service_name        => 'alt_service',
           :service_type        => 'alt_placement',
           :region              => 'RegionTwo',
@@ -53,12 +59,15 @@ describe 'placement::keystone::auth' do
         :configure_endpoint  => false,
         :service_name        => 'alt_service',
         :service_type        => 'alt_placement',
-        :service_description => 'Alternative Placement Service',
+        :service_description => 'Alternative OpenStack Placement Service',
         :region              => 'RegionTwo',
         :auth_name           => 'alt_placement',
         :password            => 'placement_password',
         :email               => 'alt_placement@alt_localhost',
         :tenant              => 'alt_service',
+        :roles               => ['admin', 'service'],
+        :system_scope        => 'alt_all',
+        :system_roles        => ['admin', 'member', 'reader'],
         :public_url          => 'https://10.10.10.10:80',
         :internal_url        => 'http://10.10.10.11:81',
         :admin_url           => 'http://10.10.10.12:81',
